{ config, lib, pkgs, inputs, ... }:

{
  imports = [
    ./hardware-configuration.nix
    ../desktop.nix
  ];

  boot.loader = {
    systemd-boot = {
      enable = true;
      graceful = true;
      netbootxyz.enable = true;
    };
    efi.canTouchEfiVariables = true;
  };

  networking = {
    hostId = "c5e68d78";
    networkmanager.enable = true;
    firewall.trustedInterfaces = [ "lxdbr0" "virbr0" ]; # Work around https://github.com/NixOS/nixpkgs/issues/263359
  };

  virtualisation = {
    libvirtd.enable = true;
    lxd.enable = true;
  };

  services.nix-serve = {
    enable = true;
    secretKeyFile = "/var/cache-priv-key.pem";
  };

  services.nginx = {
    enable = true;
    recommendedProxySettings = true;
    virtualHosts = {
      "odyssey.mesh.vimium.net" = {
        locations."/".proxyPass = "http://${config.services.nix-serve.bindAddress}:${toString config.services.nix-serve.port}";
      };
    };
  };

  modules = {
    desktop = {
      apps.qbittorrent.enable = true;
      browsers = {
        firefox.enable = true;
      };
      gaming.emulators = {
        gamecube.enable = true;
        ps2.enable = true;
        ps3.enable = true;
        psp.enable = true;
        wii.enable = true;
        xbox.enable = true;
      };
      media.graphics = {
        modeling.enable = true;
        raster.enable = true;
        vector.enable = true;
      };
      media.recording = {
        audio.enable = true;
        video.enable = true;
      };
    };
    dev = {
      node.enable = true;
    };
    editors = {
      neovim.enable = true;
      vscode.enable = true;
    };
    hardware.presonus-studio.enable = true;
    security = {
      gpg.enable = true;
      pass.enable = true;
    };
    services = {
      borgmatic = {
        enable = true;
        directories = [
          "/home/jordan/Documents"
        ];
        repoPath = "ssh://iqwu22oq@iqwu22oq.repo.borgbase.com/./repo";
      };
    };
    shell = {
      git.enable = true;
      zsh.enable = true;
    };
  };

  system.stateVersion = "22.11";
}
